@@ -22,5 +22,5 @@ from SRP.SRPMath.AstroCoordInput import AstroCoordInput
 
 def GetObj (ra,dec):
     coord = AstroCoordInput(ra,dec)
-    nb = ephem.readdb('SRPTNGPALO Object,f|M|sp,'+str(ephem.hours(ephem.degrees(str(coord.RA))))+','+str(ephem.degrees(str(coord.DEC)))+',0,'+'2000')
+    nb = ephem.readdb('SRPTNGPAOLO Object,f|M|sp,'+str(ephem.hours(ephem.degrees(str(coord.RA))))+','+str(ephem.degrees(str(coord.DEC)))+',0,'+'2000')
     return nb
\ No newline at end of file
